summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--source3/passdb/lookup_sid.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/source3/passdb/lookup_sid.c b/source3/passdb/lookup_sid.c
index f3103c0cc0..567ddac3db 100644
--- a/source3/passdb/lookup_sid.c
+++ b/source3/passdb/lookup_sid.c
@@ -383,7 +383,7 @@ BOOL lookup_name(TALLOC_CTX *mem_ctx,
/************************************************************************
Names from smb.conf can be unqualified. eg. valid users = foo
- These names should never map to a remote name. Try lp_workgroup()\foo,
+ These names should never map to a remote name. Try global_sam_name()\foo,
and then "Unix Users"\foo (or "Unix Groups"\foo).
************************************************************************/
@@ -402,9 +402,9 @@ BOOL lookup_name_smbconf(TALLOC_CTX *mem_ctx,
ret_sid, ret_type);
}
/* Try with our own domain name. */
qualified_name = talloc_asprintf(mem_ctx, "%s\\%s",
- lp_workgroup(),
+ get_global_sam_name(),
full_name );
if (!qualified_name) {
return False;
@@ -402,9 +402,9 @@ BOOL lookup_name_smbconf(TALLOC_CTX *mem_ctx,
ret_sid, ret_type);
}
- /* Try with our own domain name. */
+ /* Try with our own SAM name. */
qualified_name = talloc_asprintf(mem_ctx, "%s\\%s",